---
layout: page
title: proxmox_virtual_environment_hagroup
parent: Data Sources
subcategory: Virtual Environment
description: |-
  Retrieves information about a specific High Availability group.
---

# Data Source: proxmox_virtual_environment_hagroup

Retrieves information about a specific High Availability group.

## Example Usage

```terraform
// This will fetch the set of HA group identifiers...
data "proxmox_virtual_environment_hagroups" "all" {}

// ...which we will go through in order to fetch the whole data on each group.
data "proxmox_virtual_environment_hagroup" "example" {
  for_each = data.proxmox_virtual_environment_hagroups.all.group_ids
  group    = each.value
}

output "proxmox_virtual_environment_hagroups_full" {
  value = data.proxmox_virtual_environment_hagroup.example
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `group` (String) The identifier of the High Availability group to read.

### Read-Only

- `comment` (String) The comment associated with this group
- `id` (String) The unique identifier of this resource.
- `no_failback` (Boolean) A flag that indicates that failing back to a higher priority node is disabled for this HA group.
- `nodes` (Map of Number) The member nodes for this group. They are provided as a map, where the keys are the node names and the values represent their priority: integers for known priorities or `null` for unset priorities.
- `restricted` (Boolean) A flag that indicates that other nodes may not be used to run resources associated to this HA group.
