---
layout: page
title: proxmox_virtual_environment_acme_dns_plugin
parent: Resources
subcategory: Virtual Environment
description: |-
  Manages an ACME plugin in a Proxmox VE cluster.
---

# Resource: proxmox_virtual_environment_acme_dns_plugin

Manages an ACME plugin in a Proxmox VE cluster.

## Example Usage

```terraform
resource "proxmox_virtual_environment_acme_dns_plugin" "example" {
  plugin = "test"
  api    = "aws"
  data = {
    AWS_ACCESS_KEY_ID     = "EXAMPLE"
    AWS_SECRET_ACCESS_KEY = "EXAMPLE"
  }
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `api` (String) API plugin name.
- `plugin` (String) ACME Plugin ID name.

### Optional

- `data` (Map of String) DNS plugin data.
- `digest` (String) SHA1 digest of the current configuration. Prevent changes if current configuration file has a different digest. This can be used to prevent concurrent modifications.
- `disable` (Boolean) Flag to disable the config.
- `validation_delay` (Number) Extra delay in seconds to wait before requesting validation. Allows to cope with a long TTL of DNS records (0 - 172800).

## Import

Import is supported using the following syntax:

```shell
#!/usr/bin/env sh
# ACME accounts can be imported using their name, e.g.:
terraform import proxmox_virtual_environment_acme_dns_plugin.example test
```
