---
layout: page
title: proxmox_virtual_environment_apt_repository
parent: Resources
subcategory: Virtual Environment
description: |-
  Manages an APT repository of a Proxmox VE node.
---

# Resource: proxmox_virtual_environment_apt_repository

Manages an APT repository of a Proxmox VE node.

## Example Usage

```terraform
resource "proxmox_virtual_environment_apt_repository" "example" {
  enabled   = true
  file_path = "/etc/apt/sources.list"
  index     = 0
  node      = "pve"
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `file_path` (String) The absolute path of the source list file that contains this repository.
- `index` (Number) The index within the defining source list file.
- `node` (String) The name of the target Proxmox VE node.

### Optional

- `enabled` (Boolean) Indicates the activation status.

### Read-Only

- `comment` (String) The associated comment.
- `components` (List of String) The list of components.
- `file_type` (String) The format of the defining source list file.
- `id` (String) The unique identifier of this APT repository resource.
- `package_types` (List of String) The list of package types.
- `suites` (List of String) The list of package distributions.
- `uris` (List of String) The list of repository URIs.

## Import

Import is supported using the following syntax:

```shell
#!/usr/bin/env sh
# An APT repository can be imported using a comma-separated list consisting of the name of the Proxmox VE node,
# the absolute source list file path, and the index in the exact same order, e.g.:
terraform import proxmox_virtual_environment_apt_repository.example pve,/etc/apt/sources.list,0
```
