---
layout: page
title: proxmox_virtual_environment_apt_standard_repository
parent: Resources
subcategory: Virtual Environment
description: |-
  Manages an APT standard repository of a Proxmox VE node.
---

# Resource: proxmox_virtual_environment_apt_standard_repository

Manages an APT standard repository of a Proxmox VE node.

## Example Usage

```terraform
resource "proxmox_virtual_environment_apt_standard_repository" "example" {
  handle = "no-subscription"
  node   = "pve"
}

resource "proxmox_virtual_environment_apt_repository" "example" {
  enabled   = true
  file_path = proxmox_virtual_environment_apt_standard_repository.example.file_path
  index     = proxmox_virtual_environment_apt_standard_repository.example.index
  node      = proxmox_virtual_environment_apt_standard_repository.example.node
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `handle` (String) The handle of the APT standard repository. Must be `ceph-quincy-enterprise` | `ceph-quincy-no-subscription` | `ceph-quincy-test` | `ceph-reef-enterprise` | `ceph-reef-no-subscription` | `ceph-reef-test` | `enterprise` | `no-subscription` | `test`.
- `node` (String) The name of the target Proxmox VE node.

### Read-Only

- `description` (String) The description of the APT standard repository.
- `file_path` (String) The absolute path of the source list file that contains this standard repository.
- `id` (String) The unique identifier of this APT standard repository resource.
- `index` (Number) The index within the defining source list file.
- `name` (String) The name of the APT standard repository.
- `status` (Number) Indicates the activation status.

## Import

Import is supported using the following syntax:

```shell
#!/usr/bin/env sh
# An APT standard repository can be imported using a comma-separated list consisting of the name of the Proxmox VE node,
# and the standard repository handle in the exact same order, e.g.:
terraform import proxmox_virtual_environment_apt_standard_repository.example pve,no-subscription
```
