---
layout: page
title: proxmox_virtual_environment_hagroup
parent: Resources
subcategory: Virtual Environment
description: |-
  Manages a High Availability group in a Proxmox VE cluster.
---

# Resource: proxmox_virtual_environment_hagroup

Manages a High Availability group in a Proxmox VE cluster.

## Example Usage

```terraform
resource "proxmox_virtual_environment_hagroup" "example" {
  group   = "example"
  comment = "This is a comment."

  # Member nodes, with or without priority.
  nodes = {
    node1 = null
    node2 = 2
    node3 = 1
  }

  restricted  = true
  no_failback = false
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `group` (String) The identifier of the High Availability group to manage.
- `nodes` (Map of Number) The member nodes for this group. They are provided as a map, where the keys are the node names and the values represent their priority: integers for known priorities or `null` for unset priorities.

### Optional

- `comment` (String) The comment associated with this group
- `no_failback` (Boolean) A flag that indicates that failing back to a higher priority node is disabled for this HA group. Defaults to `false`.
- `restricted` (Boolean) A flag that indicates that other nodes may not be used to run resources associated to this HA group. Defaults to `false`.

### Read-Only

- `id` (String) The unique identifier of this resource.

## Import

Import is supported using the following syntax:

```shell
#!/usr/bin/env sh
# HA groups can be imported using their name, e.g.:
terraform import proxmox_virtual_environment_hagroup.example example
```
