---
layout: page
title: proxmox_virtual_environment_hardware_mapping_dir
parent: Resources
subcategory: Virtual Environment
description: |-
  Manages a directory mapping in a Proxmox VE cluster.
---

# Resource: proxmox_virtual_environment_hardware_mapping_dir

Manages a directory mapping in a Proxmox VE cluster.

## Example Usage

```terraform
resource "proxmox_virtual_environment_hardware_mapping_dir" "example" {
  comment = "This is a comment"
  name    = "example"
  # The actual map of devices.
  map = [
    {
      node = "pve"
      path = "/mnt/data"
    },
  ]
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `map` (Attributes Set) The actual map of devices for the hardware mapping. (see [below for nested schema](#nestedatt--map))
- `name` (String) The name of this directory mapping.

### Optional

- `comment` (String) The comment of this directory mapping.

### Read-Only

- `id` (String) The unique identifier of this directory mapping resource.

<a id="nestedatt--map"></a>
### Nested Schema for `map`

Required:

- `node` (String) The node this mapping applies to.
- `path` (String) The path of the map. For directory mappings the path is required and refers to the POSIX path of the directory as visible from the node.

## Import

Import is supported using the following syntax:

```shell
#!/usr/bin/env sh
# A directory mapping can be imported using their name, e.g.:
terraform import proxmox_virtual_environment_hardware_mapping_dir.example example
```
