---
layout: page
title: proxmox_virtual_environment_hardware_mapping_pci
parent: Resources
subcategory: Virtual Environment
description: |-
  Manages a PCI hardware mapping in a Proxmox VE cluster.
---

# Resource: proxmox_virtual_environment_hardware_mapping_pci

Manages a PCI hardware mapping in a Proxmox VE cluster.

## Example Usage

```terraform
resource "proxmox_virtual_environment_hardware_mapping_pci" "example" {
  comment = "This is a comment"
  name    = "example"
  # The actual map of devices.
  map = [
    {
      comment = "This is a device specific comment"
      id      = "8086:5916"
      # This is an optional attribute, but causes a mapping to be incomplete when not defined.
      iommu_group = 0
      node        = "pve"
      path        = "0000:00:02.0"
      # This is an optional attribute, but causes a mapping to be incomplete when not defined.
      subsystem_id = "8086:2068"
    },
  ]
  mediated_devices = true
}
```

<!-- schema generated by tfplugindocs -->
## Schema

### Required

- `map` (Attributes Set) The actual map of devices for the PCI hardware mapping. (see [below for nested schema](#nestedatt--map))
- `name` (String) The name of this PCI hardware mapping.

### Optional

- `comment` (String) The comment of this PCI hardware mapping.
- `mediated_devices` (Boolean) Indicates whether to enable mediated devices.

### Read-Only

- `id` (String) The unique identifier of this PCI hardware mapping resource.

<a id="nestedatt--map"></a>
### Nested Schema for `map`

Required:

- `id` (String) The ID of the map.
- `node` (String) The node name of the map.
- `path` (String) The path of the map.

Optional:

- `comment` (String) The comment of the mapped PCI device.
- `iommu_group` (Number) The IOMMU group of the map. Not mandatory for the Proxmox VE API call, but causes a PCI hardware mapping to be incomplete when not set
- `subsystem_id` (String) The subsystem ID group of the map. Not mandatory for the Proxmox VE API call, but causes a PCI hardware mapping to be incomplete when not set

## Import

Import is supported using the following syntax:

```shell
#!/usr/bin/env sh
# A PCI hardware mapping can be imported using their name, e.g.:
terraform import proxmox_virtual_environment_hardware_mapping_pci.example example
```
